@@ -8,14 +8,19 @@
 
 use super::super::Core;
 use crate::messaging::{
-    node::NodeMsg,
+    node::{NodeMsg, SectionAuth},
     section_info::{GetSectionResponse, SectionInfoMsg},
     DstLocation, SectionAuthorityProvider, WireMsg,
 };
 use crate::routing::{
-    error::Result, network::NetworkUtils, peer::PeerUtils, routing_api::command::Command,
-    section::SectionUtils, SectionAuthorityProviderUtils,
+    error::{Error, Result},
+    network::NetworkUtils,
+    peer::PeerUtils,
+    routing_api::command::Command,
+    section::SectionUtils,
+    SectionAuthorityProviderUtils,
 };
+use secured_linked_list::SecuredLinkedList;
 use std::net::SocketAddr;
 use xor_name::XorName;
 
@@ -107,4 +112,38 @@ impl Core {
 
         Ok(cmd)
     }
+
+    pub(crate) fn handle_section_knowledge_msg(
+        &mut self,
+        signed_section_auth: SectionAuth<SectionAuthorityProvider>,
+        proof_chain: SecuredLinkedList,
+        msg: Option<Box<NodeMsg>>,
+        src_name: XorName,
+        sender: SocketAddr,
+    ) -> Result<Vec<Command>> {
+        // TODO: if the update fails due to not trusted SAP/prof-chain,
+        // we may not need to resend the message as it's probably a sybil peer.
+        let _ = self.network.update_remote_section_sap(
+            signed_section_auth,
+            &proof_chain,
+            self.section.chain(),
+        );
+
+        if let Some(node_msg) = msg {
+            // This included message shall have been sent from us originally.
+            // Now re-send it with the latest knowledge of the destination section.
+            let dst_section_pk = self
+                .network
+                .key_by_name(&src_name)
+                .map_err(|_| Error::NoMatchingSection)?;
+
+            Ok(vec![self.send_direct_message(
+                (src_name, sender),
+                *node_msg,
+                dst_section_pk,
+            )?])
+        } else {
+            Ok(vec![])
+        }
+    }
 }
